@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: Debug.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: Debug.cpp 1198 2005-08-26 08:18:50Z mosu $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 	\author Moritz Bunkus <moritz @ bunkus.org>
 */
@@ -133,12 +133,12 @@ inline int ADbg::_OutPut(const char * format,va_list params) const
 			sprintf(myformat,"%04d/%02d/%02d %02d:%02d:%02ld.%03ld UTC : %s\r\n",
 					now->tm_year, now->tm_mon, now->tm_mday,
 					now->tm_hour, now->tm_min, tv.tv_sec,
-					tv.tv_usec / 1000, format);
+					(long)tv.tv_usec / 1000, format);
 		else
 			sprintf(myformat,"%04d/%02d/%02d %02d:%02d:%02ld.%03ld UTC : %s - %s\r\n",
 					now->tm_year, now->tm_mon, now->tm_mday,
 					now->tm_hour, now->tm_min, tv.tv_sec,
-					tv.tv_usec / 1000, prefix, format);
+					(long)tv.tv_usec / 1000, prefix, format);
 		
 	} else {
 		if (prefix[0] == '\0')
