@@ -3,7 +3,7 @@
 **
 ** <file/class description>
 **
-** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
+** Copyright (C) 2002-2005 Steve Lhomme.  All rights reserved.
 **
 ** This file is part of libebml.
 **
@@ -30,7 +30,7 @@
 
 /*!
 	\file
-	\version \$Id: EbmlVoid.cpp 1033 2005-01-10 22:49:42Z robux4 $
+	\version \$Id: EbmlVoid.cpp 1232 2005-10-15 15:56:52Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "ebml/EbmlVoid.h"
@@ -83,10 +83,10 @@ uint64 EbmlVoid::ReplaceWith(EbmlElement & EltToReplaceWith, IOCallback & output
 	  EbmlVoid aTmp;
 	  aTmp.SetSize(HeadSize() + Size - EltToReplaceWith.GetSize() - EltToReplaceWith.HeadSize() - 1); // 1 is the length of the Void ID
 	  int HeadBefore = aTmp.HeadSize();
-	  aTmp.SetSize(aTmp.GetSize() - CodedSizeLength(aTmp.Size, aTmp.SizeLength));
+	  aTmp.SetSize(aTmp.GetSize() - CodedSizeLength(aTmp.Size, aTmp.SizeLength, aTmp.bSizeIsFinite));
 	  int HeadAfter = aTmp.HeadSize();
 	  if (HeadBefore != HeadAfter) {
-	    aTmp.SetSizeLength(CodedSizeLength(aTmp.Size, aTmp.SizeLength) - (HeadAfter - HeadBefore));
+		  aTmp.SetSizeLength(CodedSizeLength(aTmp.Size, aTmp.SizeLength, aTmp.bSizeIsFinite) - (HeadAfter - HeadBefore));
 	  }
 	  aTmp.RenderHead(output, false, bKeepIntact); // the rest of the data is not rewritten
 	}
@@ -116,13 +116,13 @@ uint64 EbmlVoid::Overwrite(const EbmlElement & EltToVoid, IOCallback & output, b
 
 	// compute the size of the voided data based on the original one
 	Size = EltToVoid.GetSize() + EltToVoid.HeadSize() - 1; // 1 for the ID
-	Size -= CodedSizeLength(Size, SizeLength);
+	Size -= CodedSizeLength(Size, SizeLength, bSizeIsFinite);
 	// make sure we handle even the strange cases
 	//uint32 A1 = Size + HeadSize();
 	//uint32 A2 = EltToVoid.GetSize() + EltToVoid.HeadSize();
 	if (Size + HeadSize() != EltToVoid.GetSize() + EltToVoid.HeadSize()) {
 		Size--;
-		SetSizeLength(CodedSizeLength(Size, SizeLength) + 1);
+		SetSizeLength(CodedSizeLength(Size, SizeLength, bSizeIsFinite) + 1);
 	}
 
 	if (Size != 0) {
