@@ -28,7 +28,7 @@
 
 /*!
 	\file
-	\version \$Id: MemIOCallback.cpp 639 2004-07-09 20:59:14Z mosu $
+	\version \$Id: MemIOCallback.cpp 693 2004-07-31 08:56:28Z robux4 $
 	\author Jory Stone <jcsston @ toughguy.net>
 */
 
@@ -68,7 +68,7 @@ uint32 MemIOCallback::read(void *Buffer, size_t Size)
 	if (Buffer == NULL || Size < 1)
 		return 0;
 	//If the size is larger than than the amount left in the buffer
-	if (Size > dataBufferTotalSize - dataBufferPos)
+	if (Size + dataBufferPos > dataBufferTotalSize)
 	{
 		//We will only return the remaining data
 		memcpy(Buffer, dataBuffer + dataBufferPos, dataBufferTotalSize - dataBufferPos);
